| Title: | Database Support for 'orderly' |
|---|---|
| Description: | Access databases from 'orderly' while running reports. Includes the basic 'SQL' support originally included in 'orderly' for establishing connections and setting up data for use within a report. |
| Authors: | Rich FitzJohn [aut, cre], Imperial College of Science, Technology and Medicine [cph] |
| Maintainer: | Rich FitzJohn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.5 |
| Built: | 2026-05-21 10:09:16 UTC |
| Source: | https://github.com/mrc-ide/orderly.db |
Create a persistent connection object to the database
orderly_db_connection(database = NULL, instance = NULL)orderly_db_connection(database = NULL, instance = NULL)
database |
The name of the database. This can be omitted (or
|
instance |
The instance of the database (within a given
|
The connection object
Extract data from a database
orderly_db_query(query, database = NULL, instance = NULL, name = NULL)orderly_db_query(query, database = NULL, instance = NULL, name = NULL)
query |
Query to evaluate |
database |
The name of the database. This can be omitted (or
|
instance |
The instance of the database (within a given
|
name |
An optional name that you can use to look up this query in your metadata. |
The extracted data
Create temporary view
orderly_db_view(query, as, database = NULL, instance = NULL)orderly_db_view(query, as, database = NULL, instance = NULL)
query |
Query to create view from |
as |
Name of the view in the database |
database |
The name of the database. This can be omitted (or
|
instance |
The instance of the database (within a given
|
Undefined